@@ -38,7 +38,7 @@ SEXP GSE_Rcpp(SEXP X, SEXP N, SEXP P, SEXP Mu0, SEXP S0, SEXP Tol, SEXP Maxiter,
     umat miss_group_unique = as<umat>(Miss_group_unique);
     uvec miss_group_counts = as<uvec>(Miss_group_counts);
     vec tuning_const_group = as<vec>(Tuning_const_group);
-    int print_step = as<int>(Print_step);
+    // int print_step = as<int>(Print_step);
     double bdp = as<double>(Bdp);
     
     // individual weights (new 2014-07-23)
@@ -99,7 +99,7 @@ SEXP GSE_Rcpp(SEXP X, SEXP N, SEXP P, SEXP Mu0, SEXP S0, SEXP Tol, SEXP Maxiter,
     }
     while( (ep > tol) && (error_code == 0) && (iter <= maxiter) );
 
-    int ximp_update = update(x, Omega, Sigma0, false, mu0, stilde0, miss_group_unique, miss_group_counts, tuning_const_group, wgts_mem, wgtsp_mem, ximp_mem);
+    // int ximp_update = update(x, Omega, Sigma0, false, mu0, stilde0, miss_group_unique, miss_group_counts, tuning_const_group, wgts_mem, wgtsp_mem, ximp_mem);
 
     return List::create( Named("S")=Sigma0, Named("mu")=mu0, Named("stilde0")=stilde0, 
         Named("weights")=wgts, Named("weightsprm")=wgtsp,Named("ximp")=ximp,
@@ -173,7 +173,7 @@ mat iterS( mat x, mat sigma0, mat sigmak, bool equalsig, mat mu, double sk, umat
                                 nn++;
                             }
                         }
-                        xi.col(mm) = x( span(rowid_start, rowid_end ), j );
+                        xi.col(mm) = x( arma::span(rowid_start, rowid_end ), j );
                         sigmaku_nonmiss.col(mm) = sigmak.col(j);	
                         mu_nonmiss(0, mm) = mu(0, j);
                         mm++;
@@ -230,7 +230,7 @@ mat iterS( mat x, mat sigma0, mat sigmak, bool equalsig, mat mu, double sk, umat
                 } else{
                     xpred = x.row(rowid_start + m);
                 }
-                for(int jj=0; jj < p; jj++) ximp(rowid_start + m, jj) = xpred(0, jj); // new July 28, 2014 for outputing the imputed data matrix
+                for(unsigned int jj=0; jj < p; jj++) ximp(rowid_start + m, jj) = xpred(0, jj); // new July 28, 2014 for outputing the imputed data matrix
                 mu1 += weight1 * xpred;
                 xpred -= mu;
                 Sigma1 += weight1 * (trans(xpred) * xpred) + weight2 * Ck;
@@ -296,7 +296,7 @@ int update( mat x, mat sigma0, mat sigmak, bool equalsig, mat mu, double sk, uma
                                 nn++;
                             }
                         }
-                        xi.col(mm) = x( span(rowid_start, rowid_end ), j );
+                        xi.col(mm) = x( arma::span(rowid_start, rowid_end ), j );
                         sigmaku_nonmiss.col(mm) = sigmak.col(j);	
                         mu_nonmiss(0, mm) = mu(0, j);
                         mm++;
@@ -334,7 +334,7 @@ int update( mat x, mat sigma0, mat sigmak, bool equalsig, mat mu, double sk, uma
                 double md = as_scalar(xii * sigmak_nonmiss_inv * trans(xii));
                 double md2 = md*dee_ratio / (tuning_const_group(i) * sk );
                 double weight1 = rho1p( md2 ) * dee_ratio;
-                double weight2 = weight1 * (md / ppi);
+                // double weight2 = weight1 * (md / ppi);
 
                 wgts(rowid_start + m) = weight1;
                 wgtsp(rowid_start + m) = rho1pp( md2)*dee_ratio/tuning_const_group(i);
@@ -344,7 +344,7 @@ int update( mat x, mat sigma0, mat sigmak, bool equalsig, mat mu, double sk, uma
                 } else{
                     xpred = x.row(rowid_start + m);
                 }
-                for(int jj=0; jj < p; jj++) ximp(rowid_start + m, jj) = xpred(0, jj); // new July 28, 2014 for outputing the imputed data matrix
+                for(unsigned int jj=0; jj < p; jj++) ximp(rowid_start + m, jj) = xpred(0, jj); // new July 28, 2014 for outputing the imputed data matrix
                 xpred -= mu;
             }
             rowid_start = rowid_start + miss_group_counts(i);
@@ -411,7 +411,7 @@ mat pmd_adj(mat x, mat sigma0, mat sigmak, bool equalsig, mat mu, umat miss_grou
                                 nn++;
                             }
                         }
-                        xi.col(mm) = x( span(rowid_start, rowid_end ), j );
+                        xi.col(mm) = x( arma::span(rowid_start, rowid_end ), j );
                         mu_nonmiss(0, mm) = mu(0, j);
                         mm++;
                     }
